export class BaseFlag {
    enabled;
    value;
    isDefault;
    constructor(value, enabled, isDefault) {
        this.value = value;
        this.enabled = enabled;
        this.isDefault = isDefault;
    }
}
export class DefaultFlag extends BaseFlag {
    constructor(value, enabled) {
        super(value, enabled, true);
    }
}
export class Flag extends BaseFlag {
    featureId;
    featureName;
    constructor(params) {
        super(params.value, params.enabled, !!params.isDefault);
        this.featureId = params.featureId;
        this.featureName = params.featureName;
    }
    static fromFeatureStateModel(fsm, identityId) {
        return new Flag({
            value: fsm.getValue(identityId),
            enabled: fsm.enabled,
            featureId: fsm.feature.id,
            featureName: fsm.feature.name
        });
    }
    static fromAPIFlag(flagData) {
        return new Flag({
            enabled: flagData['enabled'],
            value: flagData['feature_state_value'] ?? flagData['value'],
            featureId: flagData['feature']['id'],
            featureName: flagData['feature']['name']
        });
    }
}
export class Flags {
    flags = {};
    defaultFlagHandler;
    analyticsProcessor;
    constructor(data) {
        this.flags = data.flags;
        this.defaultFlagHandler = data.defaultFlagHandler;
        this.analyticsProcessor = data.analyticsProcessor;
    }
    static fromFeatureStateModels(data) {
        const flags = {};
        for (const fs of data.featureStates) {
            flags[fs.feature.name] = Flag.fromFeatureStateModel(fs, data.identityID);
        }
        return new Flags({
            flags: flags,
            defaultFlagHandler: data.defaultFlagHandler,
            analyticsProcessor: data.analyticsProcessor
        });
    }
    static fromAPIFlags(data) {
        const flags = {};
        for (const flagData of data.apiFlags) {
            flags[flagData['feature']['name']] = Flag.fromAPIFlag(flagData);
        }
        return new Flags({
            flags: flags,
            defaultFlagHandler: data.defaultFlagHandler,
            analyticsProcessor: data.analyticsProcessor
        });
    }
    allFlags() {
        return Object.values(this.flags);
    }
    getFlag(featureName) {
        const flag = this.flags[featureName];
        if (!flag) {
            if (this.defaultFlagHandler) {
                return this.defaultFlagHandler(featureName);
            }
            return { enabled: false, isDefault: true, value: undefined };
        }
        if (this.analyticsProcessor && flag.featureId) {
            this.analyticsProcessor.trackFeature(flag.featureName);
        }
        return flag;
    }
    getFeatureValue(featureName) {
        return this.getFlag(featureName).value;
    }
    isFeatureEnabled(featureName) {
        return this.getFlag(featureName).enabled;
    }
}
